==> hs-dev-helper-0.0.2.tgz: package/js-toolkit/fragments/SwiperJsClass.js <==
//https://swiperjs.com/get-started#use-swiper-from-cdn
export default class {
	
	debug = false
	containers = []
	options = {}

	constructor(selector, options) { 
		this.log('Initializing if exists..');
		
		this.options = options
		this.containers = document.querySelectorAll(selector);

		if (this.containers.length) {
			this.log('Container exists..');
			this.loadStylesheet();

			if (typeof Swiper == 'function') { 
				this.log('Swiper exists as function..');
				this.init();
			}
			else{
				this.log('Swiper not found! Loading from cdn..');
				this.loadJSLibsAndInit();
			}
		}
		else {
			this.log(`Container with selector ${selector} not found!`);
		}
	}

	init() {
		this.log('Initializing swiper..');
		
		[...this.containers].forEach((el) => {
			let swiper = el.querySelector('.swiper-container');
			this.log(swiper);

			let options = Object.assign({}, {
				loop: false,
				grabCursor: true,
				centeredSlides: true,
				navigation : {
					nextEl: el.querySelector('.swiper-button-next'),
					prevEl: el.querySelector('.swiper-button-prev'),
				},
				pagination : {
					el: el.querySelector('.swiper-pagination'),
					type: 'bullets',
					clickable: true,
				}
			}, this.options);
			this.log(options);			
			
			let elOptions = Object.assign({}, options, JSON.parse(swiper.getAttribute('data-swiper')) || {})
			new Swiper(swiper,elOptions);
		});
	}

	loadStylesheet(){
		let link = document.createElement("link");
		link.type = "text/css";
		link.rel = "stylesheet";
		link.href = 'https://cdn.jsdelivr.net/npm/swiper@8/swiper-bundle.min.css';
		document.head.appendChild(link);

		link.onload = () => {
			this.log('Swiper CSS loaded')
		}
	}

	loadJSLibsAndInit() {
		const script = document.createElement('script');
		script.src = 'https://cdn.jsdelivr.net/npm/swiper@8/swiper-bundle.min.js';
		document.body.appendChild(script);
		
		script.onload = () => {
			this.log('Swiper JS script loaded')
			this.init();
		}
	}

	log = (this.debug ? console.log : () => { })
	
}

==> hs-dev-helper-0.1.5.tgz: package/js-toolkit/fragments/SwiperJsClass.js <==
//https://swiperjs.com/get-started#use-swiper-from-cdn
export default class {
	
	debug = false
	containers = []
	options = {}

	constructor(selector, options) { 
		this.log('Initializing if exists..');
		
		this.options = options
		this.containers = document.querySelectorAll(selector);

		if (this.containers.length) {
			this.log('Container exists..');
			this.loadStylesheet();

			if (typeof Swiper == 'function') { 
				this.log('Swiper exists as function..');
				this.init();
			}
			else{
				this.log('Swiper not found! Loading from cdn..');
				this.loadJSLibsAndInit();
			}
		}
		else {
			this.log(`Container with selector ${selector} not found!`);
		}
	}

	init() {
		this.log('Initializing swiper..');
		
		[...this.containers].forEach((el) => {
			let swiper = el.querySelector('.swiper-container');
			this.log(swiper);

			let options = Object.assign({}, {
				loop: false,
				grabCursor: true,
				centeredSlides: true,
				navigation : {
					nextEl: el.querySelector('.swiper-button-next'),
					prevEl: el.querySelector('.swiper-button-prev'),
				},
				pagination : {
					el: el.querySelector('.swiper-pagination'),
					type: 'bullets',
					clickable: true,
				}
			}, this.options);
			this.log(options);			
			
			let swiperAttr = swiper.hasAttribute('data-swiper') ? swiper.getAttribute('data-swiper') : {}
			let elOptions = Object.assign({}, options, JSON.parse(swiperAttr) || {})
			new Swiper(swiper,elOptions);
		});
	}

	loadStylesheet(){
		let link = document.createElement("link");
		link.type = "text/css";
		link.rel = "stylesheet";
		link.href = 'https://cdn.jsdelivr.net/npm/swiper@8/swiper-bundle.min.css';
		document.head.appendChild(link);

		link.onload = () => {
			this.log('Swiper CSS loaded')
		}
	}

	loadJSLibsAndInit() {
		const script = document.createElement('script');
		script.src = 'https://cdn.jsdelivr.net/npm/swiper@8/swiper-bundle.min.js';
		document.body.appendChild(script);
		
		script.onload = () => {
			this.log('Swiper JS script loaded')
			this.init();
		}
	}

	log = (this.debug ? console.log : () => { })
	
}
